@@ -1,3 +1,4 @@
+import os
 import logging
 import time
 import json
@@ -129,6 +130,12 @@ def handle_abnormal(message: str, status: int, header: dict = {'Content-Type': '
 
 
 def handle_download_file(file_path: str, file_name: str):
+    if not os.path.exists(os.path.join(file_path, file_name)):
+        handle_abnormal(
+            message='文件(普通下载)路径不存在',
+            status=400,
+            other={'file_path': file_path, 'file_name': file_name}
+        )
     response = make_response(send_from_directory(
         file_path,  # 本地目录的path
         file_name,  # 文件名(带扩展名)
@@ -141,9 +148,15 @@ def handle_download_file(file_path: str, file_name: str):
 
 def handle_download_flow(file_path: str, file_name: str):
     complete_path = os.path.join(file_path, file_name)
-    # 流式读取文件
+    if not os.path.exists(complete_path):
+        handle_abnormal(
+            message='文件(流传输)路径不存在',
+            status=400,
+            other={'complete_path': complete_path}
+        )
 
     def send_file():
+        # 流式读取文件
         with open(complete_path, 'rb') as target_file:
             while 1:
                 data = target_file.read(20 * 1024 * 1024)   # 每次读取20M
